@@ -3,7 +3,7 @@
  *
  * convert between latex special chars and unicode
  *
- * Copyright (c) Chris Putnam 2004-8
+ * Copyright (c) Chris Putnam 2004-2009
  *
  * Source code released under the GPL
  *
@@ -39,7 +39,7 @@ static struct latex_chars latex_chars[] = {
    { 194, "{\\^A}",  "\\^{A}",  "\\^A"  }, /*               with circumflex */
    { 195, "{\\~A}",  "\\~{A}",  "\\~A"  }, /*               with tilde */
    { 196, "{\\\"A}", "\\\"{A}", "\\\"A" }, /*               with diuresis */
-   { 197, "\\AA",    "",        ""      }, /*               with ring above */
+   { 197, "{\\AA}",  "",        ""      }, /*               with ring above */
 
                                            /* Latin Small a */
    { 224, "{\\`a}",  "\\`{a}",  "\\`a"  }, /*               with grave */
@@ -47,13 +47,13 @@ static struct latex_chars latex_chars[] = {
    { 226, "{\\^a}",  "\\^{a}",  "\\^a"  }, /*               with circumflex */
    { 227, "{\\~a}",  "\\~{a}",  "\\~a"  }, /*               with tilde */
    { 228, "{\\\"a}", "\\\"{a}", "\\\"a" }, /*               with diuresis */
-   { 229, "\\aa",    "",        ""      }, /*               with ring above */
+   { 229, "{\\aa}",  "",        ""      }, /*               with ring above */
 
    { 198, "{\\AE}",  "\\AE",    ""      }, /* Latin Capital AE */
    { 230, "{\\ae}",  "\\ae",    ""      }, /* Latin Small ae */
 
-   { 199, "\\c{C}",  "",        ""      }, /* Latin Capital C with cedilla */
-   { 231, "\\c{c}",  "",        ""      }, /* Latin small c with cedilla*/
+   { 199, "{\\c{C}}","\\c{C}",  ""      }, /* Latin Capital C with cedilla */
+   { 231, "{\\c{c}}","\\c{c}",  ""      }, /* Latin small c with cedilla*/
    { 262, "{\\'C}",  "\\'{C}",  "\\'C"  }, /* Latin Capital C with acute */
    { 263, "{\\'c}",  "\\'{c}",  "\\'c"  }, /* Latin small c with acute */
 
@@ -260,8 +260,8 @@ static struct latex_chars latex_chars[] = {
    { 8261, "{\\textlquill}", "\\textlquill", "" },         /* Left quill &#x2045; */
    { 8262, "{\\textrquill}", "\\textrquill", "" },         /* Right quill &#x2046; */
 
-   { 8211, "--",      "{\\textendash}", "\\textendash" },     /* En-dash &#x2013; */
    { 8212, "---",     "{\\textemdash}", "\\textemdash" },     /* Em-dash &#x2014; */
+   { 8211, "--",      "{\\textendash}", "\\textendash" },     /* En-dash &#x2013; */
    { 8230, "\\ldots", "{\\textellipsis}", "\\textellipsis" },   /* Ellipsis &#x2026; */
 
    { 8194, "\\enspace", "\\hspace{.5em}", "" }, /* En-space &#x2002; */
@@ -332,18 +332,22 @@ latex2char( char *s, unsigned int *pos, int *unicode )
 	int i, j, l[3];
 	p = &( s[*pos] );
 	value = (unsigned char) *p;
-	for ( i=0; i<nlatex_chars; ++i ) {
-		q[0] = latex_chars[i].bib1;
-		l[0] = strlen( q[0] );
-		q[1] = latex_chars[i].bib2;
-		l[1] = strlen( q[1] );
-		q[2] = latex_chars[i].bib3;
-		l[2] = strlen( q[2] );
-		for ( j=0; j<3; ++j ) {
-			if ( l[j] && !strncmp( p, q[j], l[j] ) ) {
-				*pos = *pos + l[j];
-				*unicode = 1;
-				return latex_chars[i].unicode;
+	if ( value=='{' || value=='\\' || value=='~' || 
+	     value=='$' || value=='\'' || value=='`' || 
+	     value=='-' || value=='^' ) {
+		for ( i=0; i<nlatex_chars; ++i ) {
+			q[0] = latex_chars[i].bib1;
+			l[0] = strlen( q[0] );
+			q[1] = latex_chars[i].bib2;
+			l[1] = strlen( q[1] );
+			q[2] = latex_chars[i].bib3;
+			l[2] = strlen( q[2] );
+			for ( j=0; j<3; ++j ) {
+				if ( l[j] && !strncmp( p, q[j], l[j] ) ) {
+					*pos = *pos + l[j];
+					*unicode = 1;
+					return latex_chars[i].unicode;
+				}
 			}
 		}
 	}
