@@ -1,7 +1,7 @@
 /*
  * newstr.c
  *
- * Copyright (c) Chris Putnam 1999-2008
+ * Copyright (c) Chris Putnam 1999-2009
  *
  * Source code released under the GPL
  *
@@ -13,6 +13,7 @@
  */
 #include <stdio.h>
 #include <stdlib.h>
+#include <stdarg.h>
 #include <string.h>
 #include <ctype.h>
 #include <limits.h>
@@ -89,6 +90,20 @@ newstr_init( newstr *s )
 	s->data = NULL;
 }
 
+void
+newstrs_init( newstr *s, ... )
+{
+	newstr *s2;
+	va_list ap;
+	newstr_init( s );
+	va_start( ap, s );
+	do {
+		s2 = va_arg( ap, newstr * );
+		if ( s2 ) newstr_init( s2 );
+	} while ( s2 );
+	va_end( ap );
+}
+
 static void 
 newstr_initalloc( newstr *s, unsigned long minsize )
 {
@@ -127,6 +142,20 @@ newstr_free( newstr *s )
 	s->data = NULL;
 }
 
+void
+newstrs_free( newstr *s, ... )
+{
+	newstr *s2;
+	va_list ap;
+	newstr_free( s );
+	va_start( ap, s );
+	do {
+		s2 = va_arg( ap, newstr * );
+		if ( s2 ) newstr_free( s2 );
+	} while ( s2 );
+	va_end( ap );
+}
+
 void
 newstr_empty( newstr *s )
 {
@@ -138,6 +167,20 @@ newstr_empty( newstr *s )
 	s->len = 0;
 }
 
+void
+newstrs_empty( newstr *s, ... )
+{
+	newstr *s2;
+	va_list ap;
+	newstr_empty( s );
+	va_start( ap, s );
+	do {
+		s2 = va_arg( ap, newstr * );
+		if ( s2 ) newstr_empty( s2 );
+	} while ( s2 );
+	va_end( ap );
+}
+
 void
 newstr_addchar( newstr *s, char newchar )
 {
