@@ -1,7 +1,7 @@
 /*
  * reftypes.h
  *
- * Copyright (c) Chris Putnam 2003-8
+ * Copyright (c) Chris Putnam 2003-2009
  *
  * Source code released under the GPL
  *
@@ -9,17 +9,20 @@
 #ifndef REFTYPES_H
 #define REFTYPES_H
 
-#define SIMPLE      (0)
-#define TYPE        (1)
-#define PERSON      (2)
-#define DATE        (3)
-#define PAGES       (4)
-#define SERIALNO    (5)
-#define TITLE       (6)
-#define ALWAYS      (7)
-#define BIBTEX_URL  (8)
-#define ISI_KEYWORD (9)
-#define NOTES       (10)
+#define SIMPLE       (0)
+#define TYPE         (1)
+#define PERSON       (2)
+#define DATE         (3)
+#define PAGES        (4)
+#define SERIALNO     (5)
+#define TITLE        (6)
+#define ALWAYS       (7)
+#define BIBTEX_URL   (8)
+#define ISI_KEYWORD  (9)
+#define NOTES        (10)
+#define DOI          (11)
+#define BIBTEX_SENTE (12)
+#define BIBTEX_FILE  (13)
 
 typedef struct {
 	char *oldstr;
