@@ -1,7 +1,7 @@
 /*
  * xml.c
  *
- * Copyright (c) Chris Putnam 2004-8
+ * Copyright (c) Chris Putnam 2004-2009
  *
  * Source code released under the GPL
  *
@@ -54,9 +54,18 @@ xml_new( void )
 void
 xml_free( xml *x )
 {
-	if ( x->tag ) newstr_free( x->tag );
-	if ( x->value ) newstr_free( x->value );
-	if ( x->a ) xmlattrib_free( x->a );
+	if ( x->tag ) {
+		newstr_free( x->tag );
+		free( x->tag );
+	}
+	if ( x->value ) {
+		newstr_free( x->value );
+		free( x->value );
+	}
+	if ( x->a ) {
+		xmlattrib_free( x->a );
+		free( x->a );
+	}
 	if ( x->down ) xml_free( x->down );
 	if ( x->next ) xml_free( x->next );
 }
